pub struct Spectre {}Expand description
Spectre simulator global configuration.
Implementations
Sourceimpl Spectre
impl Spectre
Sourcepub fn escape_identifier(node_name: &str) -> String
pub fn escape_identifier(node_name: &str) -> String
Escapes the given identifier to be Spectre-compatible.
Sourcepub fn instance_path(
lib: &Library<Spectre>,
conv: &NetlistLibConversion,
path: &InstancePath,
) -> String
pub fn instance_path( lib: &Library<Spectre>, conv: &NetlistLibConversion, path: &InstancePath, ) -> String
Converts a [scir::InstancePath] to a Spectre path string corresponding to
the associated instance.
Sourcepub fn node_voltage_path(
lib: &Library<Spectre>,
conv: &NetlistLibConversion,
path: &SliceOnePath,
) -> String
pub fn node_voltage_path( lib: &Library<Spectre>, conv: &NetlistLibConversion, path: &SliceOnePath, ) -> String
Converts a [SliceOnePath] to a Spectre path string corresponding to the associated
node voltage.
Sourcepub fn node_current_path(
lib: &Library<Spectre>,
conv: &NetlistLibConversion,
path: &SliceOnePath,
) -> String
pub fn node_current_path( lib: &Library<Spectre>, conv: &NetlistLibConversion, path: &SliceOnePath, ) -> String
Converts a [SliceOnePath] to a Spectre path string corresponding to the associated
terminal current.